@@ -36,6 +36,8 @@ class Converter:
     re_list_item = re.compile("^(?P<spaces>\\s*)(?P<list_mark>\\- )")
     extension_dict = {"latex": ".pdf", "latex_raw": ".pdf"}
     TOC_MARKER = "<!-- toc -->"
+    RE_SUBSECTION = re.compile("^\\\\(sub)*section\\[(?P<heading>.+?)\\]\\{(?P<content>.+)\\}$")
+    RE_HYPERTARGET = re.compile("\\\\hypertarget\\{(?P<number>.+?)\\}")
 
     def __init__(
         self,
@@ -154,6 +156,18 @@ class Converter:
         if extra_args:
             args.extend(extra_args)
         return subprocess.run(args, check=True, capture_output=True)
+    
+    @classmethod
+    def fix_subsections(cls, cnt):
+        lines = cnt.split("\n")
+        for i, line in enumerate(lines):
+            srch = cls.RE_SUBSECTION.search(line)
+            srch2 = cls.RE_HYPERTARGET.search(line)
+            if srch and srch2:
+                lines[i] = srch.group(0) + """\\label{LABEL}{}""".replace(
+                    "LABEL", srch2.group("number")
+                )
+        return "\n".join(lines)
 
     def latex_lfix_process(self, *, bn, dirname, source, target, extra_args, toc=False):
         tmpd = self.tmpd.name
@@ -172,6 +186,7 @@ class Converter:
         ).replace("ITEMEND", " \\strut}")
         cnt = self.wrap_latex_letterspace(cnt)
         cnt = self.fix_fonts(cnt, tmpd)
+        cnt = self.fix_subsections(cnt)
         with _open(new_filepath_tex, "w") as f:
             f.write(cnt)
         if self.save_raw_tex:
@@ -239,6 +254,9 @@ class Converter:
         self.latex_fix = latex_fix
         self.save_raw_tex = save_raw_tex
         self.config_path = config_path
+        if self.output_format == "latex_raw":
+            self.save_raw_tex = True
+            self.output_format = "latex"
         tmpd = self.tmpd.name
         if self.source_from_string:
             assert self.target_filepath is not None
@@ -281,16 +299,14 @@ class Converter:
                 setattr(self, k, v)
         else:
             self.config = None
-        if self.output_format in ("latex", "latex_raw") and self.template_file is None:
+        if self.output_format == "latex" and self.template_file is None:
             self.template_file = os.path.join(get_resource_dir(), "template.tex")
         if self.output_format == "docx" and self.template_file is None:
             self.template_file = os.path.join(get_resource_dir(), "template.docx")
         extension = self.get_extension(self.output_format)
 
         source = filepath
-        output_format = (
-            "latex" if self.output_format == "latex_raw" else self.output_format
-        )
+        output_format = self.output_format
         extra_args = self.pandoc_extra_args or []
         extra_args.extend(["--resource-path", self.tmpd.name])
         extra_args.extend(["--wrap=none"])
@@ -305,7 +321,7 @@ class Converter:
             extra_args.extend(["--reference-doc", self.template_file])
         elif self.output_format == "html":
             extra_args.extend(["--standalone", "--mathjax"])
-        elif self.output_format in ("latex_raw", "latex"):
+        elif self.output_format == "latex":
             extra_args.extend(
                 ["--pdf-engine", "lualatex", "--template", self.template_file]
             )
@@ -323,8 +339,6 @@ class Converter:
         if self.output_format == "html_water":
             extension = ".html"
         new_filepath_2 = os.path.join(dirname, f"{bn}{extension}")
-        if self.output_format == "latex_raw":
-            print(" ".join(["pandoc", "-o", new_filepath_2] + extra_args))
         if self.output_format == "latex" and latex_fix:
             self.latex_lfix_process(
                 bn=bn,
