@@ -107,7 +107,7 @@ class ProcessorWrapper:
             ctx_builder_args=ctx_builder_args,
             ctx_builder_kwargs=ctx_builder_kwargs,
         )
-        if output_format in ("latex", "auto"):
+        if output_format in ("latex", "latex_raw", "auto"):
             self.ff = FontFinder(get_codex_processor_dir())
         else:
             self.ff = None
